@@ -10,7 +10,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: csv_import.php 21368 2006-04-14 09:53:05Z ralfbecker $ */
+  /* $Id: csv_import.php 22410 2006-09-11 07:50:56Z ralfbecker $ */
 
 	$GLOBALS['egw_info']['flags'] = array(
 		'currentapp' => 'addressbook',
@@ -162,9 +162,11 @@
 			);
 			$config = CreateObject('phpgwapi.config','addressbook');
 			$config->read_repository();
-			while(list($name,$descr) = @each($config->config_data['custom_fields']))
+			foreach($config->config_data['customfields'] as $name => $field)
 			{
-				$addr_names[$name] = $descr;
+				if ($field['type'] == 'label' || !count($field['values']) && $field['rows'] <= 1 && $field['len'] <= 0) continue;
+
+				$addr_names[$name] = lang('Custom fields').': '.$field['label'];
 			}
 			unset($config);
 
