@@ -10,16 +10,19 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-	/* $Id: hook_deleteaccount.inc.php,v 1.7 2004/01/25 22:02:59 reinerj Exp $ */
+	/* $Id: hook_deleteaccount.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
-	$contacts = CreateObject('phpgwapi.contacts');
+	if((int)$GLOBALS['hook_values']['account_id'] > 0)
+	{
+		$contacts = CreateObject('phpgwapi.contacts');
 
-	if((int)$_POST['new_owner'] == 0)
-	{
-		$contacts->delete_all((int)$_POST['account_id']);
-	}
-	else
-	{
-		$contacts->change_owner((int)$_POST['account_id'],(int)$_POST['new_owner']);
+		if((int)$_POST['new_owner'] == 0)
+		{
+			$contacts->delete_all((int)$GLOBALS['hook_values']['account_id']);
+		}
+		else
+		{
+			$contacts->change_owner((int)$GLOBALS['hook_values']['account_id'],(int)$_POST['new_owner']);
+		}
 	}
 ?>
