@@ -10,7 +10,7 @@
 *  option) any later version.                                              *
 \**************************************************************************/
 
-/* $Id: class.bocal.inc.php 22347 2006-08-25 08:23:27Z ralfbecker $ */
+/* $Id: class.bocal.inc.php 23152 2006-12-29 08:47:28Z ralfbecker $ */
 
 require_once(EGW_INCLUDE_ROOT.'/calendar/inc/class.socal.inc.php');
 
@@ -343,8 +343,17 @@ class bocal
 		$this->total = $this->so->total;
 		$this->db2data($events,isset($params['date_format']) ? $params['date_format'] : 'ts');
 		
+		// socal::search() returns rejected group-invitations, as only the user not also the group is rejected
+		// as we cant remove them efficiantly in SQL, we kick them out here, but only if just one user is displayed
+		$remove_rejected_by_user = !$show_rejected && count($params['users']) == 1 ? $params['users'][0] : false;
+		//echo "<p align=right>remove_rejected_by_user=$remove_rejected_by_user, show_rejected=$show_rejected, params[users]=".print_r($param['users'])."</p>\n";
 		foreach($events as $id => $event)
 		{
+			if ($remove_rejected_by_user && $event['participants'][$remove_rejected_by_user] == 'R')
+			{
+				unset($events[$id]);	// remove the rejected event
+				continue;
+			}
 			if ($params['enum_groups'] && $this->enum_groups($event))
 			{
 				$events[$id] = $event;
@@ -922,7 +931,7 @@ class bocal
 			//
 			foreach($event['participants'] as $uid => $accept)
 			{
-				if ($uid == $user) 
+				if ($uid == $user || $uid < 0 && in_array($user,$this->accounts_members($uid,true))) 
 				{
 					// if we are a participant, we have an implicite READ and PRIVAT grant
 					$grants |= EGW_ACL_READ | EGW_ACL_PRIVATE;
@@ -957,6 +966,24 @@ class bocal
 		}
 		return $access;
 	}
+	
+	/**
+	 * From the accounts class in trunk: Get all members of the group $account_id
+	 *
+	 * @param int/string $accountid='' numeric account-id or alphanum. account-lid, 
+	 *	default account of the user of this session
+	 * @param boolean $just_id=false return just an array of id's and not id => lid pairs, default false
+	 * @return array with account_id ($just_id) or account_id => account_lid pairs (!$just_id)
+	 */
+	function accounts_members($account_id,$just_id=false)
+	{
+		$members = array();
+		foreach($GLOBALS['egw']->accounts->member($account_id) as $data)
+		{
+			$members[$data['account_id']] = $data['account_lid'];
+		}
+		return $just_id ? array_keys($members) : $members;
+	}
 
 	/**
 	 * Converts several date-types to a timestamp and optionaly converts user- to server-time
@@ -1371,7 +1398,7 @@ class bocal
 
 			if (!$long_status)
 			{
-				$status = $status[0];
+				$status = substr($status,0,1);
 			}
 			$names[$id] = $this->participant_name($id).' ('.$status.')';
 		}
