@@ -9,13 +9,15 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: index.php,v 1.4 2004/01/27 15:24:42 reinerj Exp $ */
+	/* $Id: index.php 20295 2006-02-15 12:31:25Z  $ */
 
-	$GLOBALS['phpgw_info']['flags'] = array(
-		'currentapp' => 'developer_tools',
-		'noheader'   => True,
-		'nofooter'   => True
+	$GLOBALS['egw_info'] = array(
+		'flags' => array(
+			'currentapp' => 'developer_tools',
+			'noheader'   => True,
+			'nofooter'   => True,
+		),
 	);
 	include('../header.inc.php');
 
-	$GLOBALS['phpgw']->redirect_link('/index.php','menuaction=developer_tools.uilangfile.index');
+	$GLOBALS['egw']->redirect_link('/index.php','menuaction=developer_tools.uilangfile.index');
