@@ -10,16 +10,22 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.db_tools.inc.php,v 1.25.2.1 2004/08/08 09:19:06 ralfbecker Exp $ */
+	/* $Id: class.db_tools.inc.php 20167 2005-12-19 04:27:19Z ralfbecker $ */
 
+	/**
+	 * db-tools: creats and modifys eGroupWare schem-files (to be installed via setup)
+	 *
+	 * @package etemplate
+	 * @subpackage tools
+	 * @author RalfBecker-AT-outdoor-training.de
+	 * @license GPL
+	 */
 	class db_tools
 	{
 		var $public_functions = array
 		(
 			'edit'         => True,
 			'needs_save'   => True,
-			//'admin'       => True,
-			//'preferences' => True
 		);
 
 		var $debug = 0;
@@ -39,48 +45,43 @@
 			'longtext'	=> 'longtext',
 			'text'		=> 'text',
 			'timestamp'	=> 'timestamp',
+			'bool'      => 'boolean',
 //			'abstime'   => 'abstime (mysql:timestamp)',
 		);
 		var $setup_header = '<?php
-  /**************************************************************************\\
-  * eGroupWare - Setup                                                       *
-  * http://www.eGroupWare.org                                                *
-  * Created by eTemplates DB-Tools written by ralfbecker@outdoor-training.de *
-  * --------------------------------------------                             *
-  * This program is free software; you can redistribute it and/or modify it  *
-  * under the terms of the GNU General Public License as published by the    *
-  * Free Software Foundation; either version 2 of the License, or (at your   *
-  * option) any later version.                                               *
-  \\**************************************************************************/
-
-  /* $Id: class.db_tools.inc.php,v 1.25.2.1 2004/08/08 09:19:06 ralfbecker Exp $ */
+	/**************************************************************************\\
+	* eGroupWare - Setup                                                       *
+	* http://www.eGroupWare.org                                                *
+	* Created by eTemplates DB-Tools written by ralfbecker@outdoor-training.de *
+	* --------------------------------------------                             *
+	* This program is free software; you can redistribute it and/or modify it  *
+	* under the terms of the GNU General Public License as published by the    *
+	* Free Software Foundation; either version 2 of the License, or (at your   *
+	* option) any later version.                                               *
+	\\**************************************************************************/
+	
+	/* $Id: class.db_tools.inc.php 20167 2005-12-19 04:27:19Z ralfbecker $ */
 ';
 
-		/*!
-		@function db_tools
-		@syntax db_tools(  )
-		@author ralfbecker
-		@abstract constructor of class
-		*/
+		/**
+		 * constructor of class
+		 */
 		function db_tools()
 		{
-			$this->editor = CreateObject('etemplate.etemplate','etemplate.db-tools.edit');
+			$this->editor =& CreateObject('etemplate.etemplate','etemplate.db-tools.edit');
 			$this->data = array();
 
-			if (!is_array($GLOBALS['phpgw_info']['apps']) || !count($GLOBALS['phpgw_info']['apps']))
+			if (!is_array($GLOBALS['egw_info']['apps']) || !count($GLOBALS['egw_info']['apps']))
 			{
 				ExecMethod('phpgwapi.applications.read_installed_apps');
 			}
-			$GLOBALS['phpgw_info']['flags']['app_header'] =
-				$GLOBALS['phpgw_info']['apps']['etemplate']['title'].' - '.lang('DB-Tools');
+			$GLOBALS['egw_info']['flags']['app_header'] =
+				$GLOBALS['egw_info']['apps']['etemplate']['title'].' - '.lang('DB-Tools');
 		}
 
-		/*!
-		@function edit
-		@syntax edit( $content='',$msg='' )
-		@author ralfbecker
-		@abstract this is the table editor (and the callback/submit-method too)
-		*/
+		/**
+		 * table editor (and the callback/submit-method too)
+		 */
 		function edit($content='',$msg = '')
 		{
 			if (isset($_GET['app']))
@@ -170,23 +171,30 @@
 				}
 				else // import
 				{
-					$oProc = CreateObject('phpgwapi.schema_proc',$GLOBALS['phpgw_info']['server']['db_type']);
-					$oProc->m_odb = $GLOBALS['phpgw']->db;
-					$oProc->m_oTranslator->_GetColumns($oProc,$content['new_table_name'],$nul);
-
-					while (list($key,$tbldata) = each ($oProc->m_oTranslator->sCol))
+					$oProc =& CreateObject('phpgwapi.schema_proc',$GLOBALS['egw_info']['server']['db_type']);
+					if (method_exists($oProc,'GetTableDefinition'))
 					{
-						$cols .= $tbldata;
+						$this->data[$this->table = $content['new_table_name']] = $oProc->GetTableDefinition($content['new_table_name']);
+					}
+					else	// to support eGW 1.0
+					{
+						$oProc->m_odb = clone($GLOBALS['egw']->db);
+						$oProc->m_oTranslator->_GetColumns($oProc,$content['new_table_name'],$nul);
+	
+						while (list($key,$tbldata) = each ($oProc->m_oTranslator->sCol))
+						{
+							$cols .= $tbldata;
+						}
+						eval('$cols = array('. $cols . ');');
+	
+						$this->data[$this->table = $content['new_table_name']] = array(
+							'fd' => $cols,
+							'pk' => $oProc->m_oTranslator->pk,
+							'fk' => $oProc->m_oTranslator->fk,
+							'ix' => $oProc->m_oTranslator->ix,
+							'uc' => $oProc->m_oTranslator->uc
+						);
 					}
-					eval('$cols = array('. $cols . ');');
-
-					$this->data[$this->table = $content['new_table_name']] = array(
-						'fd' => $cols,
-						'pk' => $oProc->m_oTranslator->pk,
-						'fk' => $oProc->m_oTranslator->fk,
-						'ix' => $oProc->m_oTranslator->ix,
-						'uc' => $oProc->m_oTranslator->uc
-					);
 				}
 			}
 			elseif ($content['editor'])
@@ -227,19 +235,18 @@
 				array('posted_table' => $this->table,'posted_app' => $this->app,'changes' => $this->changes));
 		}
 
-		/*!
-		@function needs_save
-		@syntax needs_save( $cont='',$posted_app='',$posted_table='',$edited_table='' )
-		@author ralfbecker
-		@abstract checks if table was changed and if so offers user to save changes
-		@param $cont the content of the form (if called by process_exec)
-		@param $posted_app the app the table is from
-		@param $posted_table the table-name
-		@param $edited_table the edited table-definitions
-		@result only if no changes
-		*/
-		function needs_save($cont='',$posted_app='',$posted_table='',$edited_table='')
+		/**
+		 * checks if table was changed and if so offers user to save changes
+		 *
+		 * @param array $cont the content of the form (if called by process_exec)
+		 * @param string $posted_app the app the table is from
+		 * @param string $posted_table the table-name
+		 * @param array $edited_table the edited table-definitions
+		 * @return only if no changes
+		 */
+		function needs_save($cont='',$posted_app='',$posted_table='',$edited_table='',$msg='')
 		{
+			//echo "<p>db_tools::needs_save(cont,'$posted_app','$posted_table',edited_table,'$msg')</p> cont=\n"; _debug_array($cont); echo "edited_table="; _debug_array($edited_table);
 			if (!$posted_app && is_array($cont))
 			{
 				if (isset($cont['yes']))
@@ -261,8 +268,15 @@
 						}
 						$this->setup_version($this->app,'',$tables);
 					}
-					$msg .= $this->write($this->app,$this->data) ?
-						lang('File writen') : lang('Error: writing file (no write-permission for the webserver) !!!');
+					if (!$this->write($this->app,$this->data))
+					{
+						$this->app = $cont['new_app'];	// these are the ones, the users whiches to change too
+						$this->table = $cont['new_table'];
+
+						return $this->needs_save('',$cont['app'],$cont['table'],$cont['edited_table'],
+							lang('Error: writing file (no write-permission for the webserver) !!!'));
+					}
+					$msg = lang('File writen');
 				}
 				$this->changes = array();
 				// return to edit with everything set, so the user gets the table he asked for
@@ -292,6 +306,7 @@
 				return False;	// continue edit
 			}
 			$content = array(
+				'msg' => $msg,
 				'app' => $posted_app,
 				'table' => $posted_table,
 				'version' => $this->setup_version($posted_app)
@@ -307,9 +322,9 @@
 			$new_version[$minor] = sprintf('%03d',1+$new_version[$minor]);
 			$content['new_version'] = implode('.',$new_version);
 
-			$tmpl = new etemplate('etemplate.db-tools.ask_save');
+			$tmpl =& new etemplate('etemplate.db-tools.ask_save');
 
-			if (!file_exists(PHPGW_SERVER_ROOT."/$posted_app/setup/tables_current.inc.php"))
+			if (!file_exists(EGW_SERVER_ROOT."/$posted_app/setup/tables_current.inc.php"))
 			{
 				$tmpl->disable_cells('version');
 				$tmpl->disable_cells('new_version');
@@ -319,15 +334,14 @@
 			return True;	// dont continue in edit
 		}
 
-		/*!
-		@function has_single_index
-		@syntax has_single_index( $col,$index )
-		@author ralfbecker
-		@abstract checks if there is an index (only) on $col (not a multiple index incl. $col)
-		@param $col column name
-		@param $index ix or uc array of table-defintion
-		@result True if $col has a single index
-		*/
+		/**
+		 * checks if there is an index (only) on $col (not a multiple index incl. $col)
+		 *
+		 * @param string $col column name
+		 * @param array $index ix or uc array of table-defintion
+		 * @param string &$options db specific options
+		 * @return True if $col has a single index
+		 */
 		function has_single_index($col,$index,&$options)
 		{
 			foreach($index as $in)
@@ -348,14 +362,14 @@
 			return False;
 		}
 
-		/*!
-		@function table2content
-		@syntax table2content( $table )
-		@author ralfbecker
-		@abstract creates content-array from a $table
-		@param $table table-definition, eg. $phpgw_baseline[$table_name]
-		@result content-array
-		*/
+		/**
+		 * creates content-array from a table
+		 *
+		 * @param array $table table-definition, eg. $phpgw_baseline[$table_name]
+		 * @param array &$columns returns array with column-names
+		 * @param bool $extra_index add an additional index-row
+		 * @return array content-array to call exec with
+		 */
 		function table2content($table,&$columns,$extra_index=False)
 		{
 			$content = $columns = array();
@@ -407,15 +421,14 @@
 			return $content;
 		}
 
-		/*!
-		@function content2table
-		@syntax content2table( $content )
-		@author ralfbecker
-		@abstract creates table-definition from posted content
-		@param $content posted content-array
-		@note  It sets some reasonalbe defaults for not set precisions (else setup will not install)
-		@result table-definition
-		*/
+		/**
+		 * creates table-definition from posted content
+		 *
+		 * It sets some reasonalbe defaults for not set precisions (else setup will not install)
+		 *
+		 * @param array $content posted content-array
+		 * @return table-definition
+		 */
 		function content2table($content)
 		{
 			if (!is_array($this->data))
@@ -436,7 +449,7 @@
 				$col = $content["Row$n"];
 
 				while ((list($old_name,$old_col) = @each($old_cols)) &&
-				       $this->changes[$posted_table][$old_name] == '**deleted**') ;
+							 $this->changes[$posted_table][$old_name] == '**deleted**') ;
 
 				if (($name = $col['name']) != '')		// ignoring lines without column-name
 				{
@@ -540,18 +553,15 @@
 			return $table;
 		}
 
-		/*!
-		@function read
-		@syntax read( $app,&$phpgw_baseline )
-		@author ralfbecker
-		@abstract includes $app/setup/tables_current.inc.php
-		@param $app application name
-		@param $phpgw_baseline where to put the data
-		@result True if file found, False else
-		*/
+		/**
+		 * includes $app/setup/tables_current.inc.php
+		 * @param string $app application name
+		 * @param array &$phpgw_baseline where to return the data
+		 * @return boolean True if file found, False else
+		 */
 		function read($app,&$phpgw_baseline)
 		{
-			$file = PHPGW_SERVER_ROOT."/$app/setup/tables_current.inc.php";
+			$file = EGW_SERVER_ROOT."/$app/setup/tables_current.inc.php";
 
 			$phpgw_baseline = array();
 
@@ -571,6 +581,14 @@
 			return True;
 		}
 
+		/**
+		 * returns an array as string in php-notation
+		 *
+		 * @param array $arr
+		 * @param int $depth for idention
+		 * @param string $parent
+		 * @return string
+		 */
 		function write_array($arr,$depth,$parent='')
 		{
 			if (in_array($parent,array('pk','fk','ix','uc')))
@@ -621,18 +639,16 @@
 			return $def;
 		}
 
-		/*!
-		@function write
-		@syntax write( $app,$phpgw_baseline )
-		@author ralfbecker
-		@abstract writes tabledefinitions $phpgw_baseline to file /$app/setup/tables_current.inc.php
-		@param $app app-name
-		@param $phpgw_baseline tabledefinitions
-		@return True if file writen else False
-		*/
+		/**
+		 * writes tabledefinitions $phpgw_baseline to file /$app/setup/tables_current.inc.php
+		 *
+		 * @param string $app app-name
+		 * @param array $phpgw_baseline tabledefinitions
+		 * @return boolean True if file writen else False
+		 */
 		function write($app,$phpgw_baseline)
 		{
-			$file = PHPGW_SERVER_ROOT."/$app/setup/tables_current.inc.php";
+			$file = EGW_SERVER_ROOT."/$app/setup/tables_current.inc.php";
 
 			if (file_exists($file) && ($f = fopen($file,'r')))
 			{
@@ -644,9 +660,9 @@
 				$header = substr($header,0,strpos($header,'$phpgw_baseline'));
 				fclose($f);
 
-				if (is_writable(PHPGW_SERVER_ROOT."/$app/setup"))
+				if (is_writable(EGW_SERVER_ROOT."/$app/setup"))
 				{
-					$old_file = PHPGW_SERVER_ROOT . "/$app/setup/tables_current.old.inc.php";
+					$old_file = EGW_SERVER_ROOT . "/$app/setup/tables_current.old.inc.php";
 					if (file_exists($old_file))
 					{
 						unlink($old_file);
@@ -662,7 +678,7 @@
 			{
 				$header = $this->setup_header . "\n\n";
 			}
-			if (!is_writeable(PHPGW_SERVER_ROOT."/$app/setup") || !($f = fopen($file,'w')))
+			if (!is_writeable(EGW_SERVER_ROOT."/$app/setup") || !($f = fopen($file,'w')))
 			{
 				return False;
 			}
@@ -676,21 +692,18 @@
 			return True;
 		}
 
-		/*!
-		@function setup_version
-		@syntax setup_version( $app,$new = '',$tables='' )
-		@author ralfbecker
-		@abstract reads and updates the version and tables info in file $app/setup/setup.inc.php
-		@param $app the app
-		@param $new new version number to set, if $new != ''
-		@param $tables new tables to include, if $tables != ''
-		@return the version or False if the file could not be read or written
-		*/
+		/**
+		 * reads and updates the version and tables info in file $app/setup/setup.inc.php
+		 * @param string $app the app
+		 * @param string $new new version number to set, if $new != ''
+		 * @param string $tables new tables to include (comma delimited), if != ''
+		 * @return the version or False if the file could not be read or written
+		 */
 		function setup_version($app,$new = '',$tables='')
 		{
 			//echo "<p>etemplate.db_tools.setup_version('$app','$new','$tables')</p>\n";
 
-			$file = PHPGW_SERVER_ROOT."/$app/setup/setup.inc.php";
+			$file = EGW_SERVER_ROOT."/$app/setup/setup.inc.php";
 			if (file_exists($file))
 			{
 				include($file);
@@ -700,7 +713,7 @@
 				return False;
 			}
 			if (($new == '' || $setup_info[$app]['version'] == $new) &&	
-			    (!$tables || $setup_info[$app]['tables'] && "'".implode("','",$setup_info[$app]['tables'])."'" == $tables))
+					(!$tables || $setup_info[$app]['tables'] && "'".implode("','",$setup_info[$app]['tables'])."'" == $tables))
 			{
 				return $setup_info[$app]['version'];	// no change requested or not necessary 
 			}
@@ -714,23 +727,28 @@
 			}
 			$fcontent = fread($f,filesize($file));
 			fclose ($f);
-
-			if (is_writable(PHPGW_SERVER_ROOT."/$app/setup"))
+			
+			$app_pattern = "'$app'";
+			if (preg_match("/define\('([^']+)',$app_pattern\)/",$fcontent,$matches))
 			{
-				$old_file = PHPGW_SERVER_ROOT . "/$app/setup/setup.old.inc.php";
+				$app_pattern = $matches[1];
+			}
+			if (is_writable(EGW_SERVER_ROOT."/$app/setup"))
+			{
+				$old_file = EGW_SERVER_ROOT . "/$app/setup/setup.old.inc.php";
 				if (file_exists($old_file))
 				{
 					unlink($old_file);
 				}
 				rename($file,$old_file);
 			}
-			$fnew = preg_replace('/(.*\\$'."setup_info\\['$app'\\]\\['version'\\][ \\t]*=[ \\t]*)'[^']*'(.*)/i","\\1'$new'\\2",$fcontent);
+			$fnew = preg_replace('/(.*\\$'."setup_info\\[$app_pattern\\]\\['version'\\][ \\t]*=[ \\t]*)'[^']*'(.*)/i","\\1'$new'\\2",$fcontent);
 			
 			if ($tables != '')
 			{
-				if ($setup_info[$app]['tables'])	// if there is already tables array, update it
+				if (isset($setup_info[$app]['tables']))	// if there is already tables array, update it
 				{
-					$fnew = preg_replace('/(.*\\$'."setup_info\\['$app'\\]\\['tables'\\][ \\t]*=[ \\t]*array\()[^)]*/i","\\1$tables",$fwas=$fnew);
+					$fnew = preg_replace('/(.*\\$'."setup_info\\[$app_pattern\\]\\['tables'\\][ \\t]*=[ \\t]*array\()[^)]*/i","\\1$tables",$fwas=$fnew);
 
 					if ($fwas == $fnew)	// nothing changed => tables are in single lines
 					{
@@ -739,7 +757,7 @@
 						$stage = 0;	// 0 = before, 1 = in, 2 = after tables section
 						foreach($fwas as $line)
 						{
-							if (preg_match('/(.*\\$'."setup_info\\['$app'\\]\\['tables'\\]\\[[ \\t]*\\][ \\t]*=[ \\t]*)'/i",$line,$parts))
+							if (preg_match('/(.*\\$'."setup_info\\[$app_pattern\\]\\['tables'\\]\\[[ \\t]*\\][ \\t]*=[ \\t]*)'/i",$line,$parts))
 							{
 								if ($stage == 0)	// first line of tables-section
 								{
@@ -772,10 +790,10 @@
 					{
 						$fnew = str_replace('?>','',$fnew);
 					}
-					$fnew .= "\t\$setup_info['$app']['tables'] = array($tables);\n";
+					$fnew .= "\t\$setup_info[$app_pattern]['tables'] = array($tables);\n";
 				}
 			}
-			if (!is_writeable(PHPGW_SERVER_ROOT."/$app/setup") || !($f = fopen($file,'w')))
+			if (!is_writeable(EGW_SERVER_ROOT."/$app/setup") || !($f = fopen($file,'w')))
 			{
 				return False;
 			}
@@ -785,27 +803,24 @@
 			return $new;
 		}
 
-		/*!
-		@function update
-		@syntax update( $app,$current,$version )
-		@author ralfbecker
-		@abstract updates file /$app/setup/tables_update.inc.php to reflect changes in $current
-		@param $app app-name
-		@param $current new tabledefinitions
-		@param $version new version
-		@return True if file writen else False
-		*/
+		/**
+		 * updates file /$app/setup/tables_update.inc.php to reflect changes in $current
+		 *
+		 * @param string $app app-name
+		 * @param array $current new tabledefinitions
+		 * @param string $version new version
+		 * @return boolean True if file writen else False
+		 */
 		function update($app,$current,$version)
 		{
 			//echo "<p>etemplate.db_tools.update('$app',...,'$version')</p>\n";
-
-			if (!is_writable(PHPGW_SERVER_ROOT."/$app/setup"))
+			if (!is_writable(EGW_SERVER_ROOT."/$app/setup"))
 			{
 				return False;
 			}
-			$file_baseline = PHPGW_SERVER_ROOT."/$app/setup/tables_baseline.inc.php";
-			$file_current  = PHPGW_SERVER_ROOT."/$app/setup/tables_current.inc.php";
-			$file_update   = PHPGW_SERVER_ROOT."/$app/setup/tables_update.inc.php";
+			$file_baseline = EGW_SERVER_ROOT."/$app/setup/tables_baseline.inc.php";
+			$file_current  = EGW_SERVER_ROOT."/$app/setup/tables_current.inc.php";
+			$file_update   = EGW_SERVER_ROOT."/$app/setup/tables_update.inc.php";
 
 			if (!file_exists($file_baseline) && !copy($file_current,$file_baseline))
 			{
@@ -821,7 +836,7 @@
 				$update = fread($f,filesize($file_update));
 				$update = str_replace('?>','',$update);
 				fclose($f);
-				$old_file = PHPGW_SERVER_ROOT . "/$app/setup/tables_update.old.inc.php";
+				$old_file = EGW_SERVER_ROOT . "/$app/setup/tables_update.old.inc.php";
 				if (file_exists($old_file))
 				{
 					unlink($old_file);
@@ -840,8 +855,7 @@
 			$update .= $this->update_schema($app,$current,$tables);
 
 			$update .= "
-		\$GLOBALS['setup_info']['$app']['currentver'] = '$version';
-		return \$GLOBALS['setup_info']['$app']['currentver'];
+		return \$GLOBALS['setup_info']['$app']['currentver'] = '$version';
 	}
 ?".">\n";
 			if (!($f = fopen($file_update,'w')))
@@ -857,6 +871,12 @@
 			return True;
 		}
 
+		/**
+		 * unsets all keys in an array which have a given value
+		 *
+		 * @param array &$arr
+		 * @param mixed $val value to check against
+		 */
 		function remove_from_array(&$arr,$value)
 		{
 			foreach($arr as $key => $val)
@@ -868,6 +888,14 @@
 			}
 		}
 
+		/**
+		 * creates an update-script 
+		 *
+		 * @param string $app app-name
+		 * @param array $current new table-defintion
+		 * @param string &$tables returns comma delimited list of new table-names
+		 * @return string the update-script
+		 */
 		function update_schema($app,$current,&$tables)
 		{
 			$this->read($app,$old);
@@ -877,7 +905,7 @@
 			{
 				if (!isset($current[$name]))	// table $name droped
 				{
-					$update .= "\t\t\$GLOBALS['phpgw_setup']->oProc->DropTable('$name');\n";
+					$update .= "\t\t\$GLOBALS['egw_setup']->oProc->DropTable('$name');\n";
 				}
 				else
 				{
@@ -895,13 +923,13 @@
 								$this->remove_from_array($new_table_def['fk'],$col);
 								$this->remove_from_array($new_table_def['ix'],$col);
 								$this->remove_from_array($new_table_def['uc'],$col);
-								$update .= "\t\t\$GLOBALS['phpgw_setup']->oProc->DropColumn('$name',";
+								$update .= "\t\t\$GLOBALS['egw_setup']->oProc->DropColumn('$name',";
 								$update .= $this->write_array($new_table_def,2).",'$col');\n";
 							}
 							else	// column $col renamed
 							{
 								$new_col = $this->changes[$name][$col];
-								$update .= "\t\t\$GLOBALS['phpgw_setup']->oProc->RenameColumn('$name','$col','$new_col');\n";
+								$update .= "\t\t\$GLOBALS['egw_setup']->oProc->RenameColumn('$name','$col','$new_col');\n";
 							}
 						}
 					}
@@ -924,7 +952,7 @@
 				{
 					$tables .= ($tables ? ',' : '') . "'$name'";
 
-					$update .= "\t\t\$GLOBALS['phpgw_setup']->oProc->CreateTable('$name',";
+					$update .= "\t\t\$GLOBALS['egw_setup']->oProc->CreateTable('$name',";
 					$update .= $this->write_array($table_def,2).");\n";
 				}
 				else
@@ -943,13 +971,13 @@
 							 serialize($old_norm_fd[$col]) != serialize($new_norm_fd[$col])) // column definition altered
 						{
 							$update .= "\t\t".($do_refresh ? "/* done by RefreshTable() anyway\n\t\t" : '').
-								"\$GLOBALS['phpgw_setup']->oProc->".($add ? 'Add' : 'Alter')."Column('$name','$col',";
+								"\$GLOBALS['egw_setup']->oProc->".($add ? 'Add' : 'Alter')."Column('$name','$col',";
 							$update .= $this->write_array($col_def,2) . ');' . ($do_refresh ? '*/' : '') . "\n";
 						}
 					}
 					if ($do_refresh)
 					{
-						$update .= "\t\t\$GLOBALS['phpgw_setup']->oProc->RefreshTable('$name',";
+						$update .= "\t\t\$GLOBALS['egw_setup']->oProc->RefreshTable('$name',";
 						$update .= $this->write_array($table_def,2).");\n";
 					}
 				}
@@ -961,15 +989,13 @@
 			return $update;
 		}
 
-		/*!
-		@function normalize_index
-		@abstract orders the single-colum-indices after the columns and the multicolunm ones bedind
-		@syntax normalize_index( $index,$cols )
-		@param index array with indices
-		@param cols  array with column-defs (col-name in key)
-		@author ralfbecker
-		@result the new array
-		*/
+		/**
+		 * orders the single-colum-indices after the columns and the multicolunm ones behind
+		 * 
+		 * @param array $index array with indices
+		 * @param array $cols array with column-defs (col-name is the key)
+		 * @return array the new array of indices
+		 */
 		function normalize_index($index,$cols)
 		{
 			$normalized = array();
@@ -992,13 +1018,14 @@
 			return $normalized;
 		}
 
-		/*!
-		@function normalize
-		@syntax normalize( $table )
-		@author ralfbecker
-		@abstract sets all nullable properties to True or False
-		@result the new array
-		*/
+		/**
+		 * normalices all properties in a table-definiton, eg. all nullable properties to True or False
+		 *
+		 * this is necessary to compare two table-defitions
+		 *
+		 * @param array $table table-definition
+		 * @return array the normaliced defintion
+		 */
 		function normalize($table)
 		{
 			$all_props = array('type','precision','nullable','default');
@@ -1022,13 +1049,14 @@
 			);
 		}
 
-		/*!
-		@function tables_identical
-		@syntax tables_identical( $old,$new )
-		@author ralfbecker
-		@abstract compares two table-definitions
-		@result True if they are identical or False else
-		*/
+		/**
+		 * compares two table-definitions, by comparing normaliced string-representations (serialize)
+		 *
+		 * @param array $a
+		 * @param array $b
+		 * @return boolean true if they are identical (would create an identical schema), false otherwise
+		 * 
+		 */
 		function tables_identical($a,$b)
 		{
 			$a = serialize($this->normalize($a));
@@ -1040,6 +1068,3 @@
 			return $a == $b;
 		}
 	}
-
-
-
