@@ -10,7 +10,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.nextmatch_widget.inc.php 20953 2006-04-05 15:32:05Z ralfbecker $ */
+	/* $Id: class.nextmatch_widget.inc.php 22883 2006-12-05 10:11:26Z ralfbecker $ */
 
 	/**
 	 * eTemplate Extension: Widget that show only a certain number of data-rows and allows to modifiy the rows shown (scroll).
@@ -25,6 +25,7 @@
 	 * 	'no_filter'      => True// I  disable the 1. filter
 	 * 	'no_filter2'     => True// I  disable the 2. filter (params are the same as for filter)
 	 * 	'no_cat'         => True// I  disable the cat-selectbox
+	 *  'cat_app'        =>     // I  application the cat's should be from, default app in get_rows
 	 * 	'template'       =>		// I  template to use for the rows, if not set via options
 	 * 	'header_left'    =>		// I  template to show left of the range-value, left-aligned (optional)
 	 * 	'header_right'   =>		// I  template to show right of the range-value, right-aligned (optional)
@@ -195,6 +196,8 @@
 					$obj =& CreateObject($app.'.'.$class);
 				}
 			}
+			if (!isset($value['cat_app'])) $value['cat_app'] = $app;	// if no cat_app set, use the app from the get_rows func
+
 			$max = $GLOBALS['egw_info']['user']['preferences']['common']['maxmatchs'];
 			$row_options = array();
 			foreach(array(5,12,25,50,100,200,500,999) as $n)
@@ -229,7 +232,7 @@
 					unset($value['rows']['sel_options']);
 				}
 			}
-			if ($value['start'] > $total)
+			if ($method && $total && $value['start'] >= $total)
 			{
 				$value['start'] = 0;
 				$total = $obj->$method($value,$value['rows'],$readonlys['rows']);
@@ -418,7 +421,7 @@
 			}
 			elseif ($value['last'])
 			{
-				$value['start'] = (int) (($old_value['total']-2) / $max) * $max;
+				$value['start'] = (int) (($old_value['total']-1) / $max) * $max;
 				unset($value['last']);
 				$loop = True;
 			}
