@@ -10,7 +10,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.select_widget.inc.php 22216 2006-08-12 06:15:32Z ralfbecker $ */
+	/* $Id: class.select_widget.inc.php 22883 2006-12-05 10:11:26Z ralfbecker $ */
 
 	/**
 	 * eTemplate Extension: several select-boxes with predefined eGW specific content
@@ -222,12 +222,20 @@
 					$cell['no_lang'] = True;
 					break;
 
-				case 'select-cat':	// !$type == globals cats too, $type2: extraStyleMultiselect
+				case 'select-cat':	// !$type == globals cats too, $type2: extraStyleMultiselect, $type3: application, if not current-app
 					if (!is_object($GLOBALS['egw']->categories))
 					{
 						$GLOBALS['egw']->categories =& CreateObject('phpgwapi.categories');
 					}
-					foreach((array)$GLOBALS['egw']->categories->return_sorted_array(0,False,'','','',!$type) as $cat)
+					if (!$type3 || $type3 === $GLOBALS['egw']->categories->app_name)
+					{
+						$categories =& $GLOBALS['egw']->categories;
+					}
+					else	// we need to instanciate a new cat object for the correct application
+					{
+						$categories =& new categories('',$type3);
+					}
+					foreach((array)$categories->return_sorted_array(0,False,'','','',!$type) as $cat)
 					{
 						$s = str_repeat('&nbsp;',$cat['level']) . $GLOBALS['egw']->strip_html($cat['name']);
 
