@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: tables_update.inc.php 20719 2006-03-20 19:49:55Z ralfbecker $ */
+  /* $Id: tables_update.inc.php 22504 2006-09-26 04:54:53Z ralfbecker $ */
 
 	$test[] = '0.9.11';
 	function infolog_upgrade0_9_11()
@@ -546,4 +546,13 @@
 		}
 		return $GLOBALS['setup_info']['infolog']['currentver'] = '1.2.003';
 	}
-?>
+
+
+	$test[] = '1.2.003';
+	function infolog_upgrade1_2_003()
+	{
+		// fix wrong info_responsible='' --> '0'
+		$GLOBALS['egw_setup']->oProc->query("UPDATE egw_infolog SET info_responsible='0' WHERE info_responsible=''",__LINE__,__FILE__);
+
+		return $GLOBALS['setup_info']['infolog']['currentver'] = '1.2.004';
+	}
