@@ -12,7 +12,7 @@
 	* http://www.goldenglair.com                                               *
 	\**************************************************************************/
 
-	/* $Id: class.uinews.inc.php 19910 2005-11-20 16:13:31Z nelius_weiss $ */
+	/* $Id: class.uinews.inc.php 22671 2006-10-18 06:15:59Z ralfbecker $ */
 
 	class uinews
 	{
@@ -118,7 +118,7 @@
 			{
 				$var = Array(
 					'subject' => $newsitem['subject'],
-					'submitedby' => 'Submitted by ' . $GLOBALS['egw']->common->grab_owner_name($newsitem['submittedby']) . ' on ' . $GLOBALS['egw']->common->show_date($newsitem['date']),
+					'submitedby' => lang('Submitted by') . ' ' . $GLOBALS['egw']->common->grab_owner_name($newsitem['submittedby']) . ' on ' . $GLOBALS['egw']->common->show_date($newsitem['date']),
 					'content' => $newsitem['content'],
 				);
 
@@ -246,7 +246,7 @@
 			{
 				$var = Array(
 					'subject'=> $newsitem['subject'],
-					'submitedby' => 'Submitted by ' . $GLOBALS['egw']->common->grab_owner_name($newsitem['submittedby']) . ' on ' . $GLOBALS['egw']->common->show_date($newsitem['date']),
+					'submitedby' => lang('Submitted by') . ' ' . $GLOBALS['egw']->common->grab_owner_name($newsitem['submittedby']) . ' on ' . $GLOBALS['egw']->common->show_date($newsitem['date']),
 					'content'    => nl2br($newsitem['content'])
 				);
 
