@@ -12,18 +12,19 @@
 	* http://www.goldenglair.com                                               *
 	\**************************************************************************/
 
-	/* $Id: index.php,v 1.12 2004/01/27 23:27:02 reinerj Exp $ */
+	/* $Id: index.php 20295 2006-02-15 12:31:25Z  $ */
 
-	$phpgw_info = array();
-	$GLOBALS['phpgw_info']['flags'] = array(
-		'currentapp' => 'news_admin',
-		'noheader' => True,
-		'nonavbar' => True,
+	$GLOBALS['egw_info'] = array(
+		'flags' => array(
+			'currentapp' => 'news_admin',
+			'noheader' => True,
+			'nonavbar' => True,
+		),
 	);
 	include('../header.inc.php');
 
-	$ui = CreateObject('news_admin.uinews');
+	$ui =& CreateObject('news_admin.uinews');
 	$ui->read_news();
 
-	$GLOBALS['phpgw']->common->phpgw_footer();
+	$GLOBALS['egw']->common->egw_footer();
 ?>
