@@ -6,9 +6,9 @@
 	*        and Bettina Gille <ceb@phpgroupware.org>                          *
 	* View and manipulate contact records                                      *
 	* Copyright (C) 2001, 2002 Joseph Engo, Miles Lott, Bettina Gille          *
-	* -------------------------------------------------------------------------*
+	* ------------------------------------------------------------------------ *
 	* This library is part of the eGroupWare API                               *
-	* http://www.egroupware.org                                                * 
+	* http://www.egroupware.org                                                *
 	* ------------------------------------------------------------------------ *
 	* This library is free software; you can redistribute it and/or modify it  *
 	* under the terms of the GNU Lesser General Public License as published by *
@@ -22,13 +22,13 @@
 	* along with this library; if not, write to the Free Software Foundation,  *
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
-	/* $Id: class.contacts.inc.php,v 1.24 2004/05/05 12:03:18 reinerj Exp $ */
+	/* $Id: class.contacts.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
-	if (!isset($GLOBALS['phpgw_info']['server']['contact_repository']))
+	if (!isset($GLOBALS['egw_info']['server']['contact_repository']))
 	{
-		$GLOBALS['phpgw_info']['server']['contact_repository'] = 'sql';
+		$GLOBALS['egw_info']['server']['contact_repository'] = 'sql';
 	}
-	require_once(PHPGW_API_INC . '/class.contacts_'.$GLOBALS['phpgw_info']['server']['contact_repository'] . '.inc.php');
+	require_once(EGW_API_INC . '/class.contacts_'.$GLOBALS['egw_info']['server']['contact_repository'] . '.inc.php');
 
 	class contacts extends contacts_
 	{
@@ -111,13 +111,13 @@
 						$fields[$fieldValue]=$fieldValue;
 				}
 			}
-			
+
 			// transform criteria from phpgw to egw structure
 			if(is_array($_criteria))
 			{
 				foreach($_criteria as $criteriaKey => $criteriaValue)
 				{
-					if($GLOBALS['phpgw_info']['server']['contact_repository'] == 'ldap')
+					if($GLOBALS['egw_info']['server']['contact_repository'] == 'ldap')
 					{
 						switch($criteriaKey)
 						{
@@ -144,7 +144,7 @@
 				}
 			}
 			$entries = $this->read($start,$limit,$fields,$criteria,'',$sort,$orderby);
-			
+
 			// transform entries from egw to phpgw structure
 			if(is_array($entries))
 			{
@@ -232,100 +232,44 @@
 			return ($a[1]<$b[1])?1:-1;
 		}
 
-		/*
-		comesafter ($s1, $s2)
-		Returns 1 if $s1 comes after $s2 alphabetically, 0 if not.
-		*/
-		function comesafter ($s1, $s2)
-		{
-			/*
-			We don't want to overstep the bounds of one of the strings and segfault,
-			so let's see which one is shorter.
-			*/
-			$order = 1;
-
-			if((strlen($s1) == 0))
-			{
-				return 0;
-			}
-
-			if((strlen($s2) == 0))
-			{
-				return 1;
-			}
-
-			if(strlen ($s1) > strlen ($s2))
-			{
-				$temp = $s1;
-				$s1 = $s2;
-				$s2 = $temp;
-				$order = 0;
-			}
-
-			for ($index = 0; $index < strlen ($s1); $index++)
-			{
-				/* $s1 comes after $s2 */
-				if (strtolower($s1[$index]) > strtolower($s2[$index])) { return ($order); }
-
-				/* $s1 comes before $s2 */
-				if (strtolower($s1[$index]) < strtolower($s2[$index])) { return (1 - $order); }
-			}
-				/* Special case in which $s1 is a substring of $s2 */
-
-			return ($order);
-		}
-
-		/*
-		* asortbyindex ($sortarray, $index)
+		/**
+		* To be used in usort()
 		*
-		* Sort a multi-dimensional array by a second-degree index. For instance, the 0th index
-		* of the Ith member of both the group and user arrays is a string identifier. In the
-		* case of a user array this is the username; with the group array it is the group name.
-		* asortby
+		* compares two 2-dimensional arrays a and b.
+		* The first dimension holds the key, the array is sorted by.
+		* The second dimension holds the data, that's actually string-compared.
+		*
+		* @author Carsten Wolff <wolffc@egroupware.org>
+		* @param array $fields The fields, the array is to be sorted by. Use of multiple keys is for subsorting.
+		* @param string $order ASC | DESC ascending or descending order
+		* @param array $a one item
+		* @param array $b the other item
+		* @return integer -1 | 0 | 1 equals: a is smaller | the same | larger than b.
 		*/
-		function asortbyindex ($sortarray, $index)
+		function _cmp($fields, $order, $a, $b)
 		{
-			$lastindex = count($sortarray) - 2;
-			for ($subindex = 0; $subindex < $lastindex; $subindex++)
+			foreach ($fields as $field)
 			{
-				$lastiteration = $lastindex - $subindex;
-				for ($iteration = 0; $iteration < $lastiteration; $iteration++)
+				$result = strcasecmp($a[$field][0], $b[$field][0]);
+				if ($result == 0)
 				{
-					$nextchar = 0;
-					if ($this->comesafter($sortarray[$iteration][$index], $sortarray[$iteration + 1][$index]))
-					{
-						$temp = $sortarray[$iteration];
-						$sortarray[$iteration] = $sortarray[$iteration + 1];
-						$sortarray[$iteration + 1] = $temp;
-					}
+					continue;
+				}
+				if ($order == "DESC")
+				{
+					return -$result;
+				}
+				else
+				{
+					return $result;
 				}
 			}
-			return ($sortarray);
-		}
-
-		function arsortbyindex ($sortarray, $index)
-		{
-			$lastindex = count($sortarray) - 1;
-			for ($subindex = $lastindex; $subindex > 0; $subindex--)
-			{
-				$lastiteration = $lastindex - $subindex;
-				for ($iteration = $lastiteration; $iteration > 0; $iteration--)
-				{
-					$nextchar = 0;
-					if ($this->comesafter($sortarray[$iteration][$index], $sortarray[$iteration - 1][$index]))
-					{
-						$temp = $sortarray[$iteration];
-						$sortarray[$iteration] = $sortarray[$iteration - 1];
-						$sortarray[$iteration - 1] = $temp;
-					}
-				}
-			}
-			return ($sortarray);
+			return 0;
 		}
 
 		function formatted_address($id, $business = True, $afont = '', $asize = '2')
 		{
-			$t = CreateObject('phpgwapi.Template',$GLOBALS['phpgw']->common->get_tpl_dir('addressbook'));
+			$t = CreateObject('phpgwapi.Template',$GLOBALS['egw']->common->get_tpl_dir('addressbook'));
 			$s = CreateObject('phpgwapi.sbox');
 
 			$fields = array(
@@ -349,7 +293,7 @@
 			list($address) = $this->read_single_entry($id,$fields);
 			foreach($address as $k => $val)
 			{
-				$address[$k] = $GLOBALS['phpgw']->strip_html($val);
+				$address[$k] = $GLOBALS['egw']->strip_html($val);
 			}
 
 			if ($address['title'])
@@ -386,7 +330,7 @@
 
 			if (! $country)
 			{
-				$country = $GLOBALS['phpgw_info']['user']['preferences']['common']['country'];
+				$country = $GLOBALS['egw_info']['user']['preferences']['common']['country'];
 			}
 
 			if (file_exists(PHPGW_SERVER_ROOT . SEP . 'addressbook' . SEP . 'templates' . SEP .'default' . SEP . 'format_' . strtolower($country) . '.tpl'))
@@ -400,7 +344,7 @@
 
 			if (!$afont)
 			{
-				$afont = $GLOBALS['phpgw_info']['theme']['font'];
+				$afont = $GLOBALS['egw_info']['theme']['font'];
 			}
 
 			$a .= $t->set_var('font',$afont);
@@ -412,7 +356,7 @@
 			$a .= $t->set_var('zip',$zip);
 			$a .= $t->set_var('state',$state);
 
-			if ($country != $GLOBALS['phpgw_info']['user']['preferences']['common']['country'])
+			if ($country != $GLOBALS['egw_info']['user']['preferences']['common']['country'])
 			{
 				$countryname = $s->get_full_name($country);
 				$a .= $t->set_var('country',lang($countryname));
@@ -424,7 +368,7 @@
 
 		function formatted_address_full($id, $business = True, $afont = '', $asize = '2')
 		{
-			$t = CreateObject('phpgwapi.Template',$GLOBALS['phpgw']->common->get_tpl_dir('addressbook'));
+			$t = CreateObject('phpgwapi.Template',$GLOBALS['egw']->common->get_tpl_dir('addressbook'));
 			$s = CreateObject('phpgwapi.sbox');
 
 			$fields = array(
@@ -454,7 +398,7 @@
 			list($address) = $this->read_single_entry($id,$fields);
 			foreach($address as $k => $val)
 			{
-				$address[$k] = $GLOBALS['phpgw']->strip_html($val);
+				$address[$k] = $GLOBALS['egw']->strip_html($val);
 			}
 
 			if($address['title'])
@@ -495,7 +439,7 @@
 
 			if(!$country)
 			{
-				$country = $GLOBALS['phpgw_info']['user']['preferences']['common']['country'];
+				$country = $GLOBALS['egw_info']['user']['preferences']['common']['country'];
 			}
 
 			if(file_exists(PHPGW_SERVER_ROOT . SEP . 'addressbook' . SEP . 'templates' . SEP .'default' . SEP . 'full_format_' . strtolower($country) . '.tpl'))
@@ -509,7 +453,7 @@
 
 			if(!$afont)
 			{
-				$afont = $GLOBALS['phpgw_info']['theme']['font'];
+				$afont = $GLOBALS['egw_info']['theme']['font'];
 			}
 
 			$a .= $t->set_var('font',$afont);
@@ -529,7 +473,7 @@
 			$a .= $t->set_var('fax',$address['tel_fax']);
 			$a .= $t->set_var('url',$address['url']);
 
-			if($country != $GLOBALS['phpgw_info']['user']['preferences']['common']['country'])
+			if($country != $GLOBALS['egw_info']['user']['preferences']['common']['country'])
 			{
 				$countryname = $s->get_full_name($country);
 				$a .= $t->set_var('country',lang($countryname));
@@ -541,7 +485,7 @@
 
 		function formatted_address_line($id, $business = True, $afont = '', $asize = '2')
 		{
-			$t = CreateObject('phpgwapi.Template',$GLOBALS['phpgw']->common->get_tpl_dir('addressbook'));
+			$t = CreateObject('phpgwapi.Template',$GLOBALS['egw']->common->get_tpl_dir('addressbook'));
 			$s = CreateObject('phpgwapi.sbox');
 
 			$fields = array(
@@ -564,7 +508,7 @@
 			list($address) = $this->read_single_entry($id,$fields);
 			foreach($address as $k => $val)
 			{
-				$address[$k] = $GLOBALS['phpgw']->strip_html($val);
+				$address[$k] = $GLOBALS['egw']->strip_html($val);
 			}
 
 			if($address['title'])
@@ -601,7 +545,7 @@
 
 			if(!$country)
 			{
-				$country = $GLOBALS['phpgw_info']['user']['preferences']['common']['country'];
+				$country = $GLOBALS['egw_info']['user']['preferences']['common']['country'];
 			}
 
 			if(file_exists(PHPGW_SERVER_ROOT . SEP . 'addressbook' . SEP . 'templates' . SEP .'default' . SEP . 'line_format_' . strtolower($country) . '.tpl'))
@@ -615,7 +559,7 @@
 
 			if(!$afont)
 			{
-				$afont = $GLOBALS['phpgw_info']['theme']['font'];
+				$afont = $GLOBALS['egw_info']['theme']['font'];
 			}
 
 			$a .= $t->set_var('font',$afont);
@@ -626,7 +570,7 @@
 			$a .= $t->set_var('zip',$zip);
 			$a .= $t->set_var('state',$state);
 
-			if($country != $GLOBALS['phpgw_info']['user']['preferences']['common']['country'])
+			if($country != $GLOBALS['egw_info']['user']['preferences']['common']['country'])
 			{
 				$countryname = $s->get_full_name($country);
 				$a .= $t->set_var('country','&nbsp;&nbsp;' . lang($countryname));
