@@ -10,7 +10,7 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Mike Cochrane <mike@graftonhall.co.nz>
- * @version $Revision: 22337 $
+ * @version $Revision: 22838 $
  * @since   Horde 3.0
  * @package Horde_iCalendar
  */
@@ -692,6 +692,7 @@ class Horde_iCalendar {
             }
 
             $value = $attribute['value'];
+
             switch ($name) {
             // Date fields.
             case 'DTSTAMP':
@@ -781,6 +782,17 @@ class Horde_iCalendar {
             case 'EXRULE':
             case 'RRULE':
 
+	    //Text Fields
+	    case 'SUMMARY':
+	    case 'DESCRIPTION':
+	    case 'COMMENT':
+		$value = str_replace('\\', '\\\\', $value);
+		$value = str_replace($this->_newline, '\n', $value);
+		$value = str_replace(',', '\,', $value);
+		$value = str_replace(';', '\;', $value);
+		$value = str_replace(':', '\:', $value);
+                break;
+    	
             default:
                 break;
             }
@@ -915,8 +927,8 @@ class Horde_iCalendar {
     {
         $temp = array();
         if (!is_object($value) || is_array($value)) {
-            $TZOffset  = 3600 * substr(date('O'), 0, 3);
-            $TZOffset += 60 * substr(date('O'), 3, 2);
+            $TZOffset  = 3600 * substr(date('O',$value), 0, 3);
+            $TZOffset += 60 * substr(date('O',$value), 3, 2);
             $value -= $TZOffset;
 
             $temp['zone']   = 'UTC';
@@ -929,13 +941,15 @@ class Horde_iCalendar {
         } else {
             $dateOb = (object)$value;
 
+            $TZOffset = date('O',mktime($dateOb->hour,$dateOb->min,$dateOb->sec,$dateOb->month,$dateOb->mday,$dateOb->year));
+
             // Minutes.
-            $TZOffset = substr(date('O'), 3, 2);
-            $thisMin = $dateOb->min - $TZOffset;
+            $TZOffsetMin = substr($TZOffset, 0, 1) . substr($TZOffset, 3, 2);
+            $thisMin = $dateOb->min - $TZOffsetMin;
 
             // Hours.
-            $TZOffset = substr(date('O'), 0, 3);
-            $thisHour = $dateOb->hour - $TZOffset;
+            $TZOffsetHour = substr($TZOffset, 0, 3);
+            $thisHour = $dateOb->hour - $TZOffsetHour;
 
             if ($thisMin < 0) {
                 $thisHour -= 1;
