@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	// $Id: tables_update.inc.php 22396 2006-09-05 14:12:28Z ralfbecker $
+	// $Id: tables_update.inc.php 22669 2006-10-18 05:41:42Z ralfbecker $
 
 	/* Include older eGroupWare update support */
 	include('tables_update_0_9_9.inc.php');
@@ -1207,3 +1207,10 @@
 	{
 		return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '1.2.105';
 	}
+
+
+	$test[] = '1.2.105';
+	function phpgwapi_upgrade1_2_105()
+	{
+		return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '1.2.106';
+	}
