@@ -10,7 +10,7 @@
 *  option) any later version.                                              *
 \**************************************************************************/
 
-/* $Id: class.boprojectmanager.inc.php 21574 2006-05-17 04:21:03Z ralfbecker $ */
+/* $Id: class.boprojectmanager.inc.php 22861 2006-11-22 08:19:16Z ralfbecker $ */
 
 include_once(EGW_INCLUDE_ROOT.'/projectmanager/inc/class.soprojectmanager.inc.php');
 
@@ -448,9 +448,9 @@ class boprojectmanager extends soprojectmanager
 			$criteria[$col] = $pattern;
 		}
 		$result = array();
-		foreach((array) $this->search($criteria,false,'pm_number','','%',false,'OR') as $prj )
+		foreach((array) $this->search($criteria,false,'pm_number','','%',false,'OR',false,array('pm_status'=>'active')) as $prj )
 		{
-			$result[$prj['pm_id']] = $this->link_title($prj);
+			if ($prj['pm_id']) $result[$prj['pm_id']] = $this->link_title($prj);
 		}
 		return $result;
 	}
