@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: applications.php,v 1.28 2004/03/09 21:04:10 ralfbecker Exp $ */
+  /* $Id: applications.php 20295 2006-02-15 12:31:25Z  $ */
 
 	$DEBUG = @$_POST['debug'] || @$_GET['debug'];
 	/*
@@ -19,26 +19,26 @@
 	 this will happen without further warning.
 	*/
 
-	$phpgw_info = array();
-	$GLOBALS['phpgw_info']['flags'] = array(
-		'noheader' => True,
-		'nonavbar' => True,
-		'currentapp' => 'home',
-		'noapi' => True
-	);
+	$GLOBALS['egw_info'] = array(
+		'flags' => array(
+			'noheader' => True,
+			'nonavbar' => True,
+			'currentapp' => 'home',
+			'noapi' => True
+	));
 	include ('./inc/functions.inc.php');
 
 	@set_time_limit(0);
 
 	// Check header and authentication
-	if (!$GLOBALS['phpgw_setup']->auth('Config'))
+	if (!$GLOBALS['egw_setup']->auth('Config'))
 	{
 		Header('Location: index.php');
 		exit;
 	}
 	// Does not return unless user is authorized
 
-	$tpl_root = $GLOBALS['phpgw_setup']->html->setup_tpl_dir('setup');
+	$tpl_root = $GLOBALS['egw_setup']->html->setup_tpl_dir('setup');
 	$setup_tpl = CreateObject('setup.Template',$tpl_root);
 	$setup_tpl->set_file(array(
 		'T_head' => 'head.tpl',
@@ -94,16 +94,16 @@
 		}
 	}
 
-	$GLOBALS['phpgw_setup']->loaddb();
-	$GLOBALS['phpgw_info']['setup']['stage']['db'] = $GLOBALS['phpgw_setup']->detection->check_db();
+	$GLOBALS['egw_setup']->loaddb();
+	$GLOBALS['egw_info']['setup']['stage']['db'] = $GLOBALS['egw_setup']->detection->check_db();
 
-	$setup_info = $GLOBALS['phpgw_setup']->detection->get_versions();
+	$setup_info = $GLOBALS['egw_setup']->detection->get_versions();
 	//var_dump($setup_info);exit;
-	$setup_info = $GLOBALS['phpgw_setup']->detection->get_db_versions($setup_info);
+	$setup_info = $GLOBALS['egw_setup']->detection->get_db_versions($setup_info);
 	//var_dump($setup_info);exit;
-	$setup_info = $GLOBALS['phpgw_setup']->detection->compare_versions($setup_info);
+	$setup_info = $GLOBALS['egw_setup']->detection->compare_versions($setup_info);
 	//var_dump($setup_info);exit;
-	$setup_info = $GLOBALS['phpgw_setup']->detection->check_depends($setup_info);
+	$setup_info = $GLOBALS['egw_setup']->detection->check_depends($setup_info);
 	//var_dump($setup_info);exit;
 	@ksort($setup_info);
 
@@ -115,7 +115,7 @@
 
 	if(@get_var('submit',Array('POST')))
 	{
-		$GLOBALS['phpgw_setup']->html->show_header(lang('Application Management'),False,'config',$GLOBALS['phpgw_setup']->ConfigDomain . '(' . $phpgw_domain[$GLOBALS['phpgw_setup']->ConfigDomain]['db_type'] . ')');
+		$GLOBALS['egw_setup']->html->show_header(lang('Application Management'),False,'config',$GLOBALS['egw_setup']->ConfigDomain . '(' . $GLOBALS['egw_domain'][$GLOBALS['egw_setup']->ConfigDomain]['db_type'] . ')');
 		$setup_tpl->set_var('description',lang('App install/remove/upgrade') . ':');
 		$setup_tpl->pparse('out','header');
 
@@ -123,43 +123,44 @@
 		$remove  = get_var('remove',Array('POST'));
 		$install = get_var('install',Array('POST'));
 		$upgrade = get_var('upgrade',Array('POST'));
+		
+		$do_langs = false;
 
 		if(!empty($remove) && is_array($remove))
 		{
 			$historylog = CreateObject('phpgwapi.historylog');
-			$historylog->db = $GLOBALS['phpgw_setup']->db;
+			$historylog->db = $GLOBALS['egw_setup']->db;
 
 			foreach($remove as $appname => $key)
 			{
+				$app_title = $setup_info[$appname]['title'] ? $setup_info[$appname]['title'] : $setup_info[$appname]['name'];
 				$terror = array();
 				$terror[] = $setup_info[$appname];
 
 				if ($setup_info[$appname]['tables'])
 				{
-					$GLOBALS['phpgw_setup']->process->droptables($terror,$DEBUG);
-					echo '<br>' . $setup_info[$appname]['title'] . ' ' . lang('tables dropped') . '.';
+					$GLOBALS['egw_setup']->process->droptables($terror,$DEBUG);
+					echo '<br />' . $app_title . ' ' . lang('tables dropped') . '.';
 				}
 
-				$GLOBALS['phpgw_setup']->deregister_app($setup_info[$appname]['name']);
-				echo '<br>' . $setup_info[$appname]['title'] . ' ' . lang('deregistered') . '.';
+				$GLOBALS['egw_setup']->deregister_app($setup_info[$appname]['name']);
+				echo '<br />' . $app_title . ' ' . lang('deregistered') . '.';
 
 				if ($setup_info[$appname]['hooks'])
 				{
-					$GLOBALS['phpgw_setup']->deregister_hooks($setup_info[$appname]['name']);
-					echo '<br>' . $setup_info[$appname]['title'] . ' ' . lang('hooks deregistered') . '.';
+					$GLOBALS['egw_setup']->deregister_hooks($setup_info[$appname]['name']);
+					echo '<br />' . $app_title . ' ' . lang('hooks deregistered') . '.';
 				}
-
-				$terror = $GLOBALS['phpgw_setup']->process->drop_langs($terror,$DEBUG);
-				echo '<br>' . $setup_info[$appname]['title'] . ' ' . lang('Translations removed') . '.';
+				$do_langs = true;
 
 				if ($historylog->delete($appname))
 				{
-					echo '<br>' . $setup_info[$appname]['title'] . ' ' . lang('Historylog removed') . '.';
+					echo '<br />' . $app_title . ' ' . lang('Historylog removed') . '.';
 				}
 
 				// delete all application categories and ACL
-				$GLOBALS['phpgw_setup']->db->query("DELETE FROM phpgw_categories WHERE cat_appname='$appname'",__LINE__,__FILE__);
-				$GLOBALS['phpgw_setup']->db->query("DELETE FROM phpgw_acl WHERE acl_appname='$appname'",__LINE__,__FILE__);
+				$GLOBALS['egw_setup']->db->delete($GLOBALS['egw_setup']->cats_table,array('cat_appname' => $appname),__LINE__,__FILE__);
+				$GLOBALS['egw_setup']->db->delete($GLOBALS['egw_setup']->acl_table,array('acl_appname' => $appname),__LINE__,__FILE__);
 			}
 		}
 
@@ -167,41 +168,36 @@
 		{
 			foreach($install as $appname => $key)
 			{
+				$app_title = $setup_info[$appname]['title'] ? $setup_info[$appname]['title'] : $setup_info[$appname]['name'];
 				$terror = array();
 				$terror[] = $setup_info[$appname];
 
 				if ($setup_info[$appname]['tables'])
 				{
-					$terror = $GLOBALS['phpgw_setup']->process->current($terror,$DEBUG);
-					$terror = $GLOBALS['phpgw_setup']->process->default_records($terror,$DEBUG);
-					echo '<br>' . $setup_info[$appname]['title'] . ' '
+					$terror = $GLOBALS['egw_setup']->process->current($terror,$DEBUG);
+					$terror = $GLOBALS['egw_setup']->process->default_records($terror,$DEBUG);
+					echo '<br />' . $app_title . ' '
 						. lang('tables installed, unless there are errors printed above') . '.';
 				}
 				else
 				{
-					if ($GLOBALS['phpgw_setup']->app_registered($setup_info[$appname]['name']))
+					if ($GLOBALS['egw_setup']->app_registered($setup_info[$appname]['name']))
 					{
-						$GLOBALS['phpgw_setup']->update_app($setup_info[$appname]['name']);
+						$GLOBALS['egw_setup']->update_app($setup_info[$appname]['name']);
 					}
 					else
 					{
-						$GLOBALS['phpgw_setup']->register_app($setup_info[$appname]['name']);
+						$GLOBALS['egw_setup']->register_app($setup_info[$appname]['name']);
 					}
-					echo '<br>' . $setup_info[$appname]['title'] . ' ' . lang('registered') . '.';
+					echo '<br />' . $app_title . ' ' . lang('registered') . '.';
 
 					if ($setup_info[$appname]['hooks'])
 					{
-						$GLOBALS['phpgw_setup']->register_hooks($setup_info[$appname]['name']);
-						echo '<br>' . $setup_info[$appname]['title'] . ' ' . lang('hooks registered') . '.';
+						$GLOBALS['egw_setup']->register_hooks($setup_info[$appname]['name']);
+						echo '<br />' . $app_title . ' ' . lang('hooks registered') . '.';
 					}
 				}
-				$force_en = False;
-				if($appname == 'phpgwapi')
-				{
-					$force_en = True;
-				}
-				$terror = $GLOBALS['phpgw_setup']->process->add_langs($terror,$DEBUG,$force_en);
-				echo '<br>' . $setup_info[$appname]['title'] . ' ' . lang('Translations added') . '.';
+				$do_langs = true;
 			}
 		}
 
@@ -209,34 +205,36 @@
 		{
 			foreach($upgrade as $appname => $key)
 			{
+				$app_title = $setup_info[$appname]['title'] ? $setup_info[$appname]['title'] : $setup_info[$appname]['name'];
 				$terror = array();
 				$terror[] = $setup_info[$appname];
 
-				$GLOBALS['phpgw_setup']->process->upgrade($terror,$DEBUG);
+				$GLOBALS['egw_setup']->process->upgrade($terror,$DEBUG);
 				if ($setup_info[$appname]['tables'])
 				{
-					echo '<br>' . $setup_info[$appname]['title'] . ' ' . lang('tables upgraded') . '.';
+					echo '<br />' . $app_title . ' ' . lang('tables upgraded') . '.';
 					// The process_upgrade() function also handles registration
 				}
 				else
 				{
-					echo '<br>' . $setup_info[$appname]['title'] . ' ' . lang('upgraded') . '.';
+					echo '<br />' . $app_title . ' ' . lang('upgraded') . '.';
 				}
-
-				$terror = $GLOBALS['phpgw_setup']->process->upgrade_langs($terror,$DEBUG);
-				echo '<br>' . $setup_info[$appname]['title'] . ' ' . lang('Translations upgraded') . '.';
+				$do_langs = true;
 			}
 		}
-
+		if ($do_langs)
+		{
+			$GLOBALS['egw_setup']->process->translation->drop_add_all_langs();
+		}
 		//$setup_tpl->set_var('goback',
-		echo '<br><a href="applications.php?debug='.$DEBUG.'">' . lang('Go back') . '</a>';
+		echo '<br /><a href="applications.php?debug='.$DEBUG.'">' . lang('Go back') . '</a>';
 		//$setup_tpl->pparse('out','submit');
 		$setup_tpl->pparse('out','footer');
 		exit;
 	}
 	else
 	{
-		$GLOBALS['phpgw_setup']->html->show_header(lang('Application Management'),False,'config',$GLOBALS['phpgw_setup']->ConfigDomain . '(' . $phpgw_domain[$GLOBALS['phpgw_setup']->ConfigDomain]['db_type'] . ')');
+		$GLOBALS['egw_setup']->html->show_header(lang('Application Management'),False,'config',$GLOBALS['egw_setup']->ConfigDomain . '(' . $GLOBALS['egw_domain'][$GLOBALS['egw_setup']->ConfigDomain]['db_type'] . ')');
 	}
 
 	$detail = get_var('detail',Array('GET'));
@@ -257,7 +255,6 @@
 			{
 				$i = ($i ? 0 : 1);
 
-
 				if ($key == 'tables')
 				{
 					$tblcnt = count($setup_info[$detail][$key]);
@@ -278,7 +275,7 @@
 			}
 		}
 
-		echo '<br><a href="applications.php?debug='.$DEBUG.'">' . lang('Go back') . '</a>';
+		echo '<br /><a href="applications.php?debug='.$DEBUG.'">' . lang('Go back') . '</a>';
 		$setup_tpl->pparse('out','footer');
 		exit;
 	}
@@ -288,46 +285,47 @@
 		$notables = get_var('notables',Array('GET'));
 		$setup_tpl->set_var('description',lang('Problem resolution'). ':');
 		$setup_tpl->pparse('out','header');
+		$app_title = $setup_info[$resolve]['title'] ? $setup_info[$resolve]['title'] : $setup_info[$resolve]['name'];
 
 		if(get_var('post',Array('GET')))
 		{
-			echo '"' . $setup_info[$resolve]['title'] . '" ' . lang('may be broken') . ' ';
+			echo '"' . $app_title . '" ' . lang('may be broken') . ' ';
 			echo lang('because an application it depends upon was upgraded');
-			echo '<br>';
+			echo '<br />';
 			echo lang('to a version it does not know about') . '.';
-			echo '<br>';
+			echo '<br />';
 			echo lang('However, the application may still work') . '.';
 		}
 		elseif(get_var('badinstall',Array('GET')))
 		{
-			echo '"' . $setup_info[$resolve]['title'] . '" ' . lang('is broken') . ' ';
+			echo '"' . $app_title . '" ' . lang('is broken') . ' ';
 			echo lang('because of a failed upgrade or install') . '.';
-			echo '<br>';
+			echo '<br />';
 			echo lang('Some or all of its tables are missing') . '.';
-			echo '<br>';
+			echo '<br />';
 			echo lang('You should either uninstall and then reinstall it, or attempt manual repairs') . '.';
 		}
 		elseif (!$version)
 		{
 			if($setup_info[$resolve]['enabled'])
 			{
-				echo '"' . $setup_info[$resolve]['title'] . '" ' . lang('is broken') . ' ';
+				echo '"' . $app_title . '" ' . lang('is broken') . ' ';
 			}
 			else
 			{
-				echo '"' . $setup_info[$resolve]['title'] . '" ' . lang('is disabled') . ' ';
+				echo '"' . $app_title . '" ' . lang('is disabled') . ' ';
 			}
 
 			if (!$notables)
 			{
 				if($setup_info[$resolve]['status'] == 'D')
 				{
-					echo lang('because it depends upon') . ':<br>' . "\n";
+					echo lang('because it depends upon') . ':<br />' . "\n";
 					list($depapp,$depver) = parsedep($setup_info[$resolve]['depends'],False);
                                 $depapp_count = count($depapp);
 					for ($i=0; $i<$depapp_count; $i++)
 					{
-						echo '<br>' . $depapp[$i] . ': ';
+						echo '<br />' . $depapp[$i] . ': ';
 						$list = '';
 						foreach($depver[$i] as $x => $y)
 						{
@@ -336,7 +334,7 @@
 						$list = substr($list,0,-2);
 						echo "$list\n";
 					}
-					echo '<br><br>' . lang('The table definition was correct, and the tables were installed') . '.';
+					echo '<br /><br />' . lang('The table definition was correct, and the tables were installed') . '.';
 				}
 				else
 				{
@@ -353,32 +351,32 @@
 			}
 			else
 			{
-				echo lang('because it requires manual table installation, <br>or the table definition was incorrect') . ".\n"
+				echo lang('because it requires manual table installation, <br />or the table definition was incorrect') . ".\n"
 					. lang("Please check for sql scripts within the application's directory") . '.';
 			}
-			echo '<br>' . lang('However, the application is otherwise installed') . '.';
+			echo '<br />' . lang('However, the application is otherwise installed') . '.';
 		}
 		else
 		{
-			echo $setup_info[$resolve]['title'] . ' ' . lang('has a version mismatch') . ' ';
+			echo $app_title . ' ' . lang('has a version mismatch') . ' ';
 			echo lang('because of a failed upgrade, or the database is newer than the installed version of this app') . '.';
-			echo '<br>';
+			echo '<br />';
 			echo lang('If the application has no defined tables, selecting upgrade should remedy the problem') . '.';
-			echo '<br>' . lang('However, the application is otherwise installed') . '.';
+			echo '<br />' . lang('However, the application is otherwise installed') . '.';
 		}
 
-		echo '<br><a href="applications.php?debug='.$DEBUG.'">' . lang('Go back') . '</a>';
+		echo '<br /><a href="applications.php?debug='.$DEBUG.'">' . lang('Go back') . '</a>';
 		$setup_tpl->pparse('out','footer');
 		exit;
 	}
 	else
 	{
 		$setup_tpl->set_var('description',lang('Select the desired action(s) from the available choices'));
+		$setup_tpl->set_var('action_url','applications.php');
 		$setup_tpl->pparse('out','header');
 
 		$setup_tpl->set_var('appdata',lang('Application Data'));
 		$setup_tpl->set_var('actions',lang('Actions'));
-		$setup_tpl->set_var('action_url','applications.php');
 		$setup_tpl->set_var('app_info',lang('Application Name and Status Information'));
 		$setup_tpl->set_var('app_title',lang('Application Title'));
 		$setup_tpl->set_var('app_currentver',lang('Current Version'));
@@ -392,7 +390,7 @@
 		$setup_tpl->set_var('upgrade_all',lang('Upgrade All'));
 		$setup_tpl->set_var('remove_all',lang('Remove All'));
 		$setup_tpl->set_var('lang_debug',lang('enable for extra debug-messages'));
-		$setup_tpl->set_var('debug','<input type="checkbox" name="debug" value="True"' .($DEBUG ? ' checked' : '') . '>');
+		$setup_tpl->set_var('debug','<input type="checkbox" name="debug" value="True"' .($DEBUG ? ' checked="checked"' : '') . ' />');
 		$setup_tpl->set_var('bg_color',$bgcolor[0]);
 
 		$setup_tpl->pparse('out','app_header');
@@ -411,9 +409,9 @@
 				switch($value['status'])
 				{
 					case 'C':
-						$setup_tpl->set_var('remove','<input type="checkbox" name="remove[' . $value['name'] . ']">');
+						$setup_tpl->set_var('remove',$key == 'phpgwapi' ? '&nbsp;' : '<input type="checkbox" name="remove[' . $value['name'] . ']" />');
 						$setup_tpl->set_var('upgrade','&nbsp;');
-						if (!$GLOBALS['phpgw_setup']->detection->check_app_tables($value['name']))
+						if (!$GLOBALS['egw_setup']->detection->check_app_tables($value['name']))
 						{
 							// App installed and enabled, but some tables are missing
 							$setup_tpl->set_var('instimg','table.png');
@@ -451,10 +449,10 @@
 						$setup_tpl->set_var('instalt',lang('Not Completed'));
 						if (!@$value['currentver'])
 						{
-							if ($value['tables'] && $GLOBALS['phpgw_setup']->detection->check_app_tables($value['name'],True))
+							if ($value['tables'] && $GLOBALS['egw_setup']->detection->check_app_tables($value['name'],True))
 							{
 								// Some tables missing
-								$setup_tpl->set_var('remove','<input type="checkbox" name="remove[' . $value['name'] . ']">');
+								$setup_tpl->set_var('remove',$key == 'phpgwapi' ? '&nbsp;' : '<input type="checkbox" name="remove[' . $value['name'] . ']" />');
 								$setup_tpl->set_var('resolution','<a href="applications.php?resolve=' . $value['name'] . '&badinstall=True">' . lang('Potential Problem') . '</a>');
 								$status = lang('Requires reinstall or manual repair') . ' - ' . $value['status'];
 							}
@@ -464,8 +462,11 @@
 								$setup_tpl->set_var('resolution','');
 								$status = lang('Requires upgrade') . ' - ' . $value['status'];
 							}
+							// show not installed apps without icon
+							$setup_tpl->set_var('instimg','spacer.png');
+							$setup_tpl->set_var('instalt','');
 							$setup_tpl->set_var('bg_color','CCFFCC');
-							$setup_tpl->set_var('install','<input type="checkbox" name="install[' . $value['name'] . ']">');
+							$setup_tpl->set_var('install','<input type="checkbox" name="install[' . $value['name'] . ']" />');
 							$setup_tpl->set_var('upgrade','&nbsp;');
 							$status = lang('Please install') . ' - ' . $value['status'];
 						}
@@ -474,8 +475,8 @@
 							$setup_tpl->set_var('bg_color','CCCCFF');
 							$setup_tpl->set_var('install','&nbsp;');
 							// TODO display some info about breakage if you mess with this app
-							$setup_tpl->set_var('upgrade','<input type="checkbox" name="upgrade[' . $value['name'] . ']">');
-							$setup_tpl->set_var('remove','<input type="checkbox" name="remove[' . $value['name'] . ']">');
+							$setup_tpl->set_var('upgrade','<input type="checkbox" name="upgrade[' . $value['name'] . ']" />');
+							$setup_tpl->set_var('remove',$key == 'phpgwapi' ? '&nbsp;' : '<input type="checkbox" name="remove[' . $value['name'] . ']" />');
 							$setup_tpl->set_var('resolution','');
 							$status = lang('Requires upgrade') . ' - ' . $value['status'];
 						}
@@ -484,8 +485,8 @@
 						$setup_tpl->set_var('instimg','incomplete.png');
 						$setup_tpl->set_var('instalt',lang('Not Completed'));
 						$setup_tpl->set_var('install','&nbsp;');
-						$setup_tpl->set_var('remove','<input type="checkbox" name="remove[' . $value['name'] . ']">');
-						$setup_tpl->set_var('upgrade','<input type="checkbox" name="upgrade[' . $value['name'] . ']">');
+						$setup_tpl->set_var('remove',$key == 'phpgwapi' ? '&nbsp;' : '<input type="checkbox" name="remove[' . $value['name'] . ']" />');
+						$setup_tpl->set_var('upgrade','<input type="checkbox" name="upgrade[' . $value['name'] . ']" />');
 						$setup_tpl->set_var('resolution','<a href="applications.php?resolve=' . $value['name'] . '&version=True">' . lang('Possible Solutions') . '</a>');
 						$status = lang('Version Mismatch') . ' - ' . $value['status'];
 						break;
@@ -535,6 +536,6 @@
 		$setup_tpl->set_var('cancel',lang('Cancel'));
 		$setup_tpl->pparse('out','app_footer');
 		$setup_tpl->pparse('out','footer');
-		$GLOBALS['phpgw_setup']->html->show_footer();
+		$GLOBALS['egw_setup']->html->show_footer();
 	}
 ?>
