@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.module_news.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.module_news.inc.php 22670 2006-10-18 06:10:37Z ralfbecker $ */
 
 	class module_news extends Module
 	{
@@ -164,9 +164,10 @@
 
 				default:
 				case 'complete' :
+					$data = $GLOBALS['egw']->accounts->get_account_data($newsitem['submittedby']);
 					$this->template->set_var(array(
 						'news_title' => $newsitem['subject'],
-						'news_submitter' => $GLOBALS['egw']->accounts->id2name($newsitem['submittedby']),
+						'news_submitter' => lang('Submitted by') . ' ' . $data[$newsitem['submittedby']]['fullname'],
 						'news_date' => $GLOBALS['egw']->common->show_date($newsitem['date']),
 						'news_content' => $newsitem['content']
 					));
